[![Stars](https://img.shields.io/github/stars/xikanfeng2/hcdsim?logo=GitHub&color=yellow)](https://github.com/xikanfeng2/hcdsim/stargazers)
[![PyPI](https://img.shields.io/pypi/v/hcdsim?logo=PyPI)](https://pypi.org/project/hcdsim/)
[![Downloads](https://static.pepy.tech/badge/hcdsim)](https://pepy.tech/project/hcdsim)
[![Docs](https://readthedocs.org/projects/hcdsim/badge/)](https://hcdsim.readthedocs.io)

# HCDSIM: A Single-Cell Genomics Simulator with Haplotype-Specific Copy Number Annotation.

HCDSIM: A Single-Cell Genomics Simulator with Haplotype-Specific Copy Number Annotation. Read the full [documentation] here.

![HCDSIM Workflow](docs/images/HCDSIM_Figure1.png)

<!-- ## Citation

If you use `hcdsim` in your work, please cite the `hcdsim` publication as follows:

> to do -->


[documentation]: https://hcdsim.readthedocs.io
